/****************************************************************************
** Meta object code from reading C++ file 'dbus_device.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbus_device.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_device.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DBusUPowerDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusUPowerDevice::qt_create_metaobjectdata<qt_meta_tag_ZN16DBusUPowerDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusUPowerDevice",
        "Capacity",
        "Energy",
        "EnergyFull",
        "EnergyRate",
        "IconName",
        "IsPresent",
        "Percentage",
        "PowerSupply",
        "State",
        "TimeToEmpty",
        "TimeToFull",
        "Type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Capacity'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'Energy'
        QtMocHelpers::PropertyData<double>(2, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'EnergyFull'
        QtMocHelpers::PropertyData<double>(3, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'EnergyRate'
        QtMocHelpers::PropertyData<double>(4, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'IconName'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IsPresent'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Percentage'
        QtMocHelpers::PropertyData<double>(7, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'PowerSupply'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'State'
        QtMocHelpers::PropertyData<uint>(9, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'TimeToEmpty'
        QtMocHelpers::PropertyData<qlonglong>(10, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'TimeToFull'
        QtMocHelpers::PropertyData<qlonglong>(11, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'Type'
        QtMocHelpers::PropertyData<uint>(12, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusUPowerDevice, qt_meta_tag_ZN16DBusUPowerDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusUPowerDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusUPowerDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusUPowerDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DBusUPowerDeviceE_t>.metaTypes,
    nullptr
} };

void DBusUPowerDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusUPowerDevice *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->capacity(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->energy(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->energyFull(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->energyRate(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPresent(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->percentage(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->powerSupply(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        case 9: *reinterpret_cast<qlonglong*>(_v) = _t->timeToEmpty(); break;
        case 10: *reinterpret_cast<qlonglong*>(_v) = _t->timeToFull(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->type(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusUPowerDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusUPowerDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusUPowerDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusUPowerDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
