/****************************************************************************
** Meta object code from reading C++ file 'peak.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/pipewire/peak.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'peak.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::pipewire::PwNodePeakMonitor::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::pipewire::PwNodePeakMonitor",
        "QML.Element",
        "auto",
        "nodeChanged",
        "",
        "enabledChanged",
        "peaksChanged",
        "peakChanged",
        "channelsChanged",
        "onNodeDestroyed",
        "node",
        "qs::service::pipewire::PwNodeIface*",
        "enabled",
        "peaks",
        "QList<float>",
        "peak",
        "channels",
        "QList<qs::service::pipewire::PwAudioChannel::Enum>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nodeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'peaksChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'peakChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'channelsChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onNodeDestroyed'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'node'
        QtMocHelpers::PropertyData<qs::service::pipewire::PwNodeIface*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'peaks'
        QtMocHelpers::PropertyData<QList<float>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'peak'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags, 3),
        // property 'channels'
        QtMocHelpers::PropertyData<QList<qs::service::pipewire::PwAudioChannel::Enum>>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PwNodePeakMonitor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::pipewire::PwNodePeakMonitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t>.metaTypes,
    nullptr
} };

void qs::service::pipewire::PwNodePeakMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PwNodePeakMonitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nodeChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->peaksChanged(); break;
        case 3: _t->peakChanged(); break;
        case 4: _t->channelsChanged(); break;
        case 5: _t->onNodeDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PwNodePeakMonitor::*)()>(_a, &PwNodePeakMonitor::nodeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwNodePeakMonitor::*)()>(_a, &PwNodePeakMonitor::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwNodePeakMonitor::*)()>(_a, &PwNodePeakMonitor::peaksChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwNodePeakMonitor::*)()>(_a, &PwNodePeakMonitor::peakChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwNodePeakMonitor::*)()>(_a, &PwNodePeakMonitor::channelsChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<float> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::service::pipewire::PwNodeIface**>(_v) = _t->node(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 2: *reinterpret_cast<QList<float>*>(_v) = _t->peaks(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->peak(); break;
        case 4: *reinterpret_cast<QList<qs::service::pipewire::PwAudioChannel::Enum>*>(_v) = _t->channels(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setNode(*reinterpret_cast<qs::service::pipewire::PwNodeIface**>(_v)); break;
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::service::pipewire::PwNodePeakMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::pipewire::PwNodePeakMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire17PwNodePeakMonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::pipewire::PwNodePeakMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qs::service::pipewire::PwNodePeakMonitor::nodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::service::pipewire::PwNodePeakMonitor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::pipewire::PwNodePeakMonitor::peaksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::pipewire::PwNodePeakMonitor::peakChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::service::pipewire::PwNodePeakMonitor::channelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
